@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::PotionsAndSnitches;
-$WWW::FetchStory::Fetcher::PotionsAndSnitches::VERSION = '0.1827';
+$WWW::FetchStory::Fetcher::PotionsAndSnitches::VERSION = '0.1828';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::PotionsAndSnitches - fetching module for WWW::FetchSto
 
 =head1 VERSION
 
-version 0.1827
+version 0.1828
 
 =head1 DESCRIPTION
 
@@ -29,7 +29,7 @@ $info = $self->info();
 sub info {
     my $self = shift;
     
-    my $info = "(http://www.potionsandsnitches.net) A Severus Snape + Harry Potter gen fiction archive.";
+    my $info = "(http://www.potionsandsnitches.org) A Severus Snape + Harry Potter gen fiction archive.";
 
     return $info;
 } # info
@@ -299,7 +299,7 @@ sub parse_chapter_urls {
 	if ($content =~ m#<span class="label">Chapters:\s*</span>\s*(\d+)#s)
 	{
 	    @chapters = ();
-	    my $fmt = 'http://www.potionsandsnitches.net/fanfiction/viewstory.php?action=printable&textsize=0&sid=%d&chapter=%d';
+	    my $fmt = 'http://www.potionsandsnitches.org/fanfiction/viewstory.php?action=printable&textsize=0&sid=%d&chapter=%d';
 	    my $num_ch = $1;
 	    for (my $i=1; $i <= $num_ch; $i++)
 	    {
